@@ -2,7 +2,7 @@ package Perl6::Doc;
 use 5.000;
 use File::Spec;
 
-$Perl6::Doc::VERSION = '0.35';
+$Perl6::Doc::VERSION = '0.36';
 
 sub new {
     my $class = shift;
@@ -101,12 +101,16 @@ sub perldoc {
                 $document .= '::Overview::';
                 if    ($file eq 'O03') { $document .= 'Operator'  }
                 elsif ($file eq 'O04') { $document .= 'Smartmatch'}
-                elsif ($file eq 'O06') { $document .= 'Subroutine'}
-                elsif ($file eq 'O08') { $document .= 'Variable'  }
-                elsif ($file eq 'O09') { $document .= 'Data'      }
-                elsif ($file eq 'O12') { $document .= 'Object'    }
-                elsif ($file eq 'O16') { $document .= 'File'      } 
-                else                   { $self->contents, return }
+                elsif ($file eq 'O05') { $document .= 'Reduce'    }
+                elsif ($file eq 'O07') { $document .= 'Variable'  }
+                elsif ($file eq 'O08') { $document .= 'Data'      }
+                elsif ($file eq 'O10') { $document .= 'File'      }
+                elsif ($file eq 'O12') { $document .= 'Functions' }
+                elsif ($file eq 'O14') { $document .= 'Control'   }
+                elsif ($file eq 'O15') { $document .= 'Subroutine'}
+                elsif ($file eq 'O17') { $document .= 'Object'    }
+                elsif ($file eq 'O20') { $document .= 'Rule'      }
+                else                   { $self->contents, return  }
             }
         } elsif ($sigil eq 'M') {
             $document .= '::Magazine::';
@@ -114,7 +118,8 @@ sub perldoc {
             elsif ($file eq 'M02') { $document .= 'what-is-perl-6'}
             elsif ($file eq 'M03') { $document .= 'pugs-interview'}
             elsif ($file eq 'M04') { $document .= 'everyday-perl-6'}
-            elsif ($file eq 'M05') { $document .= 'perl-6-parameter-passing'}
+            elsif ($file eq 'M05') { $document .= 'yet-another-perl-6-operator'}
+            elsif ($file eq 'M06') { $document .= 'perl-6-parameter-passing'}
             else                   { $self->contents, return }
         } else {
             $document .= '::Design::' . $file;
@@ -144,11 +149,11 @@ Possible values for document-id are:
   A01 - A20  (Perl 6 Apocalypses)
   E02 - E07  (Perl 6 Exegeses)
   S01 - S29  (Perl 6 Synopses)
-  O01 - O16  (Perl 6 Overview)
+  O01 - O20  (Perl 6 Overview)
   F01 - F02  (Perl 6 FAQ)
   T01        (Perl 6 Tutorial)
   P00 - P09  (Perl(6)Tables)
-  M01 - M05  (Mazine Articles)
+  M01 - M06  (Mazine Articles)
 
 Valid options:
   -h,  --help       Print this help screen
@@ -161,7 +166,7 @@ _
 
 sub version {
     print <<_;
-This is Perl 6 Documentation as of January 11, 2008
+This is Perl 6 Documentation as of March 20, 2008
 (bundled in Perl6-Doc-$VERSION)
 _
 }
@@ -248,19 +253,24 @@ no Design docs.
     O01  Overview
     O03  Overview::Operator
     O04  Overview::Smartmatch
-    O06  Overview::Subroutine
-    O08  Overview::Variable
-    O09  Overview::Data
-    O12  Overview::Object
-    O16  Overview::File
-    
+    O05  Overview::Reduce
+    O07  Overview::Variable
+    O08  Overview::Data
+    O10  Overview::File
+    O12  Overview::Functions
+    O14  Overview::Control
+    O15  Overview::Subroutine
+    O17  Overview::Object
+    O20  Overview::Rule
+
     T01  Tutorial perlintro
 
     M01  Report on the Perl 6 Announcement
     M02  What is Perl 6 ?
     M03  A Plan for Pugs
     M04  Everyday Perl 6
-    M05  The Beauty of Perl 6 Parameter Passing
+    M05  Yet Another Perl 6 Operator (Microarticles)
+    M06  The Beauty of Perl 6 Parameter Passing
 
 =head1 NOTES
 
@@ -357,6 +367,43 @@ Perl6::Doc provides a class method to get the raw text of a document:
 
 =head1 AUTHORS
 
+=head2 COPYRIGHT
+
+This Copyright applies only to the C<Perl6::Doc> Perl software
+distribution, not the documents bundled within.
+
+Copyright (c) 2007. Ingy dt Net, Herbert Breunung. All rights reserved.
+
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
+
+See http://www.perl.com/perl/misc/Artistic.html
+
+=cut
+
+=head2 PACKAGING
+
+Collection of docs is currently done by: 
+
+Herbert Breunung <lichtkind@cpan.org>
+
+=head2 SOURCES
+
+A couple of paragraphs from I<Perl 6 Essentials> were used for the
+overview. Most of the Bible docs (Apocalypses, Exegeses, Synopses)
+are from the official Perl development site. 
+
+L<http://dev.perl.org/perl6/>
+
+All draft Synopses, Overview, FAQ and Tutorial pages were taken out 
+of the Pugs SVN repository.
+
+L<http://svn.pugscode.org/pugs/docs/Perl6/>
+
+Articles are from:
+
+L<http://perl.com/pub/q/Article_Archive#Perl%206>
+
 =head2 SCRIBES
 
 These are the authors of the included docs, named in the order their work 
@@ -394,41 +441,4 @@ was added :
 
 * Pawel Murias <13pawel@gazeta.pl>
 
-* Herbert Breunung <lichtkind@cpan.org>
-
-=head2 SOURCES
-
-A couple of paragraphs from I<Perl 6 Essentials> were used for the
-overview. Most of the Bible docs (Apocalypses, Exegeses, Synopses)
-are from the official Perl development site. 
-
-L<http://dev.perl.org/perl6/>
-
-All draft Synopses, Overview, FAQ and Tutorial pages were taken out 
-of the Pugs SVN repository.
-
-L<http://svn.pugscode.org/pugs/docs/Perl6/>
-
-Articles are from:
-
-L<http://perl.com/pub/q/Article_Archive#Perl%206>
-
-=head2 PACKAGING
-
-Collection of docs is currently done by: 
-
-Herbert Breunung <lichtkind@cpan.org>
-
-=head2 COPYRIGHT
-
-This Copyright applies only to the C<Perl6::Doc> Perl software
-distribution, not the documents bundled within.
-
-Copyright (c) 2007. Ingy dt Net, Herbert Breunung. All rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
-See http://www.perl.com/perl/misc/Artistic.html
-
-=cut
+* Herbert Breunung <lichtkind@cpan.org>
\ No newline at end of file
